# NAME
    get_brdf

## DESCRIPTION
Estimate f/Q for a given suite of observations.

## References:
    Morel and Gentilli, Applied Optics, 35(24), 1996
    Morel et al., Applied Optics, 41(3), 2002

## Input:
    wavelength float [w]
    solar zenith angle float [s]
    chl concentration float [chl_in]
    nadir zenith angle float [n]
    azimuth angle float [a]
    f/Q table array fltarr [foq_data]

## Output:
    f/Q correction term float [fq]

## Usage:
```
get_brdf.py [-h] [--version] [--solz SOLZ] [--viewz VIEWZ] [--relaz RELAZ] [--output_file OUTPUT_FILE] chl [chl ...]

calculate Morel brdf correction

positional arguments:
  chl                   input chlorophyll

optional arguments:
  -h, --help            show this help message and exit
  --version             show program's version number and exit
  --solz SOLZ           input solar zenith angle
  --viewz VIEWZ         input view zenith angle
  --relaz RELAZ         input relative azimuth angle
  --output_file OUTPUT_FILE
                        optional output filename; default: STDOUT
```

# FUNCTIONS
    fq_table_interp()
        Load the f/Q datatable for interpolation.
    
    get_fq(solz, viewz, relaz, chl, wvl=None)
        Interpolate inputs for f/Q.

    morel_brdf(chl, solz, viewz, relaz, wvl=None, corr=False)
        Calculate the Morel brdf correction.
